==> examples-test-utils-0.12.0-sources.jar: org/kie/kogito/testcontainers/InfinispanContainer.java <==
/**
 *  Copyright 2020 Red Hat, Inc. and/or its affiliates.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.kie.kogito.testcontainers;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.testcontainers.containers.output.Slf4jLogConsumer;
import org.testcontainers.containers.wait.strategy.Wait;

/**
 * This container wraps Infinispan container
 *
 */
public class InfinispanContainer extends ConditionalGenericContainer<InfinispanContainer> {

    public static final String NAME = "infinispan";
    public static final String INFINISPAN_PROPERTY = "container.image." + NAME;

    private static final Logger LOGGER = LoggerFactory.getLogger(InfinispanContainer.class);

    public InfinispanContainer() {
        addFixedExposedPort(11222, 11222);
        withEnv("USER", "admin");
        withEnv("PASS", "admin");
        withLogConsumer(new Slf4jLogConsumer(LOGGER));
        waitingFor(Wait.forLogMessage(".*ISPN080001.*", 1));
    }

    @Override
    protected String getResourceName() {
        return NAME;
    }

    @Override
    protected void preStart() {
        setDockerImageName(System.getProperty(INFINISPAN_PROPERTY));
    }
}

==> examples-test-utils-0.13.0-sources.jar: org/kie/kogito/testcontainers/InfinispanContainer.java <==
/**
 *  Copyright 2020 Red Hat, Inc. and/or its affiliates.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.kie.kogito.testcontainers;

import org.kie.kogito.resources.TestResource;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.testcontainers.containers.GenericContainer;
import org.testcontainers.containers.output.Slf4jLogConsumer;
import org.testcontainers.containers.wait.strategy.Wait;

/**
 * This container wraps Infinispan container
 *
 */
public class InfinispanContainer extends GenericContainer<InfinispanContainer> implements TestResource {

    public static final String NAME = "infinispan";
    public static final int PORT = 11222;
    public static final String INFINISPAN_PROPERTY = "container.image." + NAME;

    private static final Logger LOGGER = LoggerFactory.getLogger(InfinispanContainer.class);

    public InfinispanContainer() {
        addExposedPort(PORT);
        withEnv("USER", "admin");
        withEnv("PASS", "admin");
        withLogConsumer(new Slf4jLogConsumer(LOGGER));
        waitingFor(Wait.forLogMessage(".*ISPN080001.*", 1));
    }

    @Override
    public int getMappedPort() {
        return getMappedPort(PORT);
    }

    @Override
    public String getResourceName() {
        return NAME;
    }

    @Override
    public void start() {
        setDockerImageName(System.getProperty(INFINISPAN_PROPERTY));
        super.start();
    }
}
